Crate spandsp

Crate spandsp 

Safe, idiomatic Rust wrappers for the spandsp telephony DSP library.

Provides RAII-managed types for codecs (G.711, G.722, G.726), DTMF generation/detection, HDLC framing, tone generation, Goertzel detection, echo cancellation, power metering, and (with the fax feature) full T.30/T.38/T.4 fax support.

Re-exports

pub use spandsp_sys;

Modules

dtmf
Safe wrappers around spandsp’s DTMF tone generation and detection.
echo
Safe wrapper around spandsp’s voice echo canceller.
error
Error types for the spandsp crate.
fax
Safe wrapper around the high-level analog FAX state machine.
fax_modems
FAX modem layer.
g711
Safe wrapper around spandsp’s G.711 codec (A-law and u-law).
g722
Safe wrappers around spandsp’s G.722 wideband codec.
g726
Safe wrapper around spandsp’s G.726 ADPCM codec.
hdlc
Safe wrappers around spandsp’s HDLC framing and deframing.
logging
Safe wrapper around spandsp’s logging subsystem.
power_meter
Safe wrapper around spandsp’s power meter.
t4
Shared types for T.4/T.6 fax image encoding and decoding.
t4_rx
T.4 image receive (decoding) support.
t4_tx
T.4 image transmit (encoding) support.
t30
Safe wrapper around the T.30 FAX protocol engine.
t38_core
Safe wrapper around the T.38 FoIP core protocol engine.
t38_gateway
Safe wrapper around the T.38 gateway.
t38_terminal
Safe wrapper around the T.38 terminal endpoint.
tone_detect
Safe wrappers around spandsp’s Goertzel tone detection.
tone_generate
Safe wrappers around spandsp’s tone generation subsystem.